@@ -4,9 +4,12 @@ from subprocess import CalledProcessError
 from typing import Mapping, Pattern, Sequence, Type, Union
 
 import click
-from click import BadParameter, ClickException
+from click import Argument, BadParameter, ClickException, Option
 from sentry_sdk import capture_exception, push_scope
 
+from sym.cli.helpers.keywords_to_options import keywords_to_options
+from sym.cli.helpers.util import get_param
+
 from .helpers.envvar_option import get_used
 
 ErrorPatterns = Mapping[Pattern[str], Type[Exception]]
@@ -28,9 +31,9 @@ def get_active_env_vars():
 
 def _format_message(self, file=None):
     msg = click.style(self.message, fg="red", bold=True)
-    if hasattr(self, "hint"):
-        styled = click.style(self.hint, fg="cyan", bold=True)
-        hint = f"\n\nHint: {styled}"
+    if hasattr(self, "hints"):
+        styled = [click.style(hint, fg="cyan", bold=True) for hint in self.hints]
+        hint = "\n\n" + "\n\n".join([f"Hint: {hint}" for hint in styled])
     else:
         hint = ""
     return f"{msg}{hint}{get_active_env_vars()}"
@@ -66,12 +69,17 @@ class CliError(ClickException, metaclass=CliErrorMeta):
 
 
 class CliErrorWithHint(CliError):
-    def __init__(self, message, hint, **kwargs) -> None:
-        self.hint = hint
+    def __init__(self, message, hints, **kwargs) -> None:
+        self.hints = hints if isinstance(hints, list) else [hints]
         super().__init__(message, **kwargs)
 
     def __str__(self):
-        return f"{self.message}\n\nHint: {self.hint}"
+        return "\n\n".join(
+            [
+                self.message,
+                *[f"Hint: {hint}" for hint in self.hints],
+            ]
+        )
 
 
 class UnavailableResourceError(CliErrorWithHint):
@@ -198,6 +206,31 @@ class ExpiredCredentials(CliErrorWithHint):
         )
 
 
+class MissingResource(CliErrorWithHint, BadParameter):
+    def __init__(
+        self,
+        profiles: Sequence[str],
+        resource_name="resource",
+    ) -> None:
+        super().__init__(
+            "You must supply a resource!",
+            self.__class__.gen_hint(resource_name, profiles),
+        )
+
+    @classmethod
+    def gen_hint(cls, resource_name, profiles) -> str:
+        return "\n".join(
+            [
+                click.style(
+                    f"These are the {resource_name}s available to you:",
+                    fg="white",
+                    reset=False,
+                ),
+                *[f"  - {key}" for key in profiles],
+            ]
+        )
+
+
 class InvalidResource(CliErrorWithHint, BadParameter, KeyError):
     def __init__(
         self,
@@ -207,15 +240,58 @@ class InvalidResource(CliErrorWithHint, BadParameter, KeyError):
     ) -> None:
         super().__init__(
             f"Invalid {resource_name} name '{resource}'",
+            self.gen_hints(resource, resource_name, profiles),
+        )
+
+    def gen_hints(self, resource, resource_name, profiles) -> Sequence[str]:
+        hints = [
             "\n".join(
                 [
                     f"Has your Sym Implementer set up {resource} yet?",
-                    f"These are the {resource_name}s available to you:",
-                    *[f"  - {key}" for key in profiles],
+                    MissingResource.gen_hint(resource_name, profiles),
                 ]
-            ),
-            report=True,
-        )
+            )
+        ]
+        if (ctx := click.get_current_context()) :
+            if ctx.command.params[0].name == resource_name:
+                args = [
+                    v
+                    for k, v in ctx.params.items()
+                    if isinstance(get_param(ctx.command, k), Argument)
+                ]
+                if len(args) == 1:
+                    return hints
+                opts = {
+                    k: v
+                    for k, v in ctx.params.items()
+                    if isinstance(get_param(ctx.command, k), Option)
+                    and get_param(ctx.command, k).get_default(ctx) != v
+                }
+                cmd = " ".join(
+                    [
+                        *keywords_to_options([opts]),
+                        (
+                            click.style(profiles[0], fg="magenta", reset=False)
+                            + click.style("", fg="white", reset=False)
+                        ),
+                        *keywords_to_options(args),
+                        *ctx.args,
+                    ]
+                )
+                hints.insert(
+                    0,
+                    "\n".join(
+                        [
+                            "Did you forget to pass a RESOURCE as the first argument?",
+                            click.style(
+                                f"e.g. `{ctx.command_path} {cmd}`",
+                                fg="white",
+                            ),
+                        ]
+                    ),
+                )
+
+        return hints
 
 
 class UnknownError(CliErrorWithHint):
