@@ -6,6 +6,7 @@ from click.exceptions import ClickException
 from sentry_sdk.api import push_scope
 
 from sym.cli.helpers.global_options import GlobalOptions
+from sym.cli.helpers.util import is_prod_mode
 
 from ..errors import UnknownError, get_active_env_vars
 from ..saml_clients.chooser import choose_saml_client
@@ -99,8 +100,10 @@ class SymGroup(Group):
             return super().invoke(ctx)
         except ClickException:
             raise
+        except KeyboardInterrupt:
+            pass
         except Exception as e:
-            if ctx.params.get("debug"):
+            if not is_prod_mode() or ctx.params.get("debug"):
                 raise e
             raise UnknownError(e)
 
