@@ -20,7 +20,7 @@ def create_fake_profile_with_ansible_bucket(resource: str) -> Profile:
 class TestAnsibleHelpers:
     """Test suite for ansible helper methods."""
 
-    def test_get_default_ansible_bucket_name(self, boto_stub, saml_client):
+    def test_get_default_ansible_bucket_name(self, click_context, boto_stub, saml_client):
         get_caller_identity_stub(boto_stub)
         actual = get_ansible_bucket_name(saml_client)
         expect(actual).to(match(f"sym-ansible-{TEST_ACCOUNT}"))
